@@ -29,6 +29,7 @@ import beagle.BeagleFlag;
 import beast.app.beastapp.BeastDialog;
 import beast.app.beastapp.BeastMain;
 import beast.app.beauti.Beauti;
+import beast.app.beauti.BeautiDoc;
 import beast.app.draw.ExtensionFileFilter;
 import beast.app.util.Version;
 import beast.core.Logger;
@@ -37,6 +38,7 @@ import beast.core.util.Log;
 import beast.util.*;
 import jam.util.IconUtils;
 import org.json.JSONException;
+import org.json.JSONObject;
 import org.xml.sax.SAXException;
 
 import javax.swing.*;
@@ -59,9 +61,9 @@ import java.util.concurrent.Executors;
  * See getUsage() for command line options.
  */
 public class BeastMCMC {
-    final public static String VERSION = "2.0 Release candidate";
+    final public static String VERSION = BEASTVersion2.INSTANCE.getVersionString();
     final public static String DEVELOPERS = "Beast 2 development team";
-    final public static String COPYRIGHT = "Beast 2 development team 2011";
+    final public static String COPYRIGHT = "Beast 2 development team " + BEASTVersion2.INSTANCE.getDateString();
 
     /**
      * number of threads used to run the likelihood beast.core *
@@ -92,6 +94,8 @@ public class BeastMCMC {
         boolean resume = false;
         boolean useStrictVersions = false;
         boolean sampleFromPrior = false;
+        boolean hasDF = false;
+        String outFile = null;
         Map<String, String> parserDefinitions = new HashMap<>();
 
         File beastFile = null;
@@ -156,6 +160,19 @@ public class BeastMCMC {
                             parserDefinitions.put(name, value);
             			}
                         i += 2;
+                    } else if (args[i].equals("-DF")) {
+                        String argFile = args[i + 1];
+                		String jsonString = BeautiDoc.load(argFile);
+                		JSONObject jsonDictionary = new JSONObject(jsonString);
+                		for (String key : jsonDictionary.keySet()) {
+                			Log.warning("Found definition of " + key + " " + jsonDictionary.getString(key).length());
+                            parserDefinitions.put(key, jsonDictionary.getString(key));
+                		}
+                		hasDF = true;
+                        i += 2;     
+                    } else if (args[i].equals("-DFout")) {
+                    	outFile = args[i + 1];                    	 
+                        i += 2;                    
                     } else if (args[i].equals("-strictversions")) {
                     	useStrictVersions = true;
                         i += 1;
@@ -178,6 +195,14 @@ public class BeastMCMC {
             throw new IllegalArgumentException("Error parsing command line arguments: " + Arrays.toString(args) + "\nArguments ignored\n\n" + getUsage());
         }
 
+        if (hasDF && outFile == null && beastFile != null) {
+        	outFile = beastFile.getAbsolutePath();
+        	if (outFile.toLowerCase().endsWith(".xml")) {
+        		outFile = outFile.substring(0, outFile.length() - 4);
+        	}
+    		outFile = outFile + ".out.xml";
+        }        	
+        
         if (beastFile == null) {
             // Not resuming so get starting options...
 
@@ -297,7 +322,7 @@ public class BeastMCMC {
             m_runnable = new JSONParser(parserDefinitions).parseFile(beastFile, sampleFromPrior);
         } else {        	
         	try {
-				m_runnable = new XMLParser(parserDefinitions).parseFile(beastFile, sampleFromPrior);
+				m_runnable = new XMLParser(parserDefinitions, outFile, hasDF).parseFile(beastFile, sampleFromPrior);
 			} catch (SAXException | ParserConfigurationException e) {
 				throw new IllegalArgumentException(e);
 			}
@@ -479,8 +504,8 @@ public class BeastMCMC {
                     int rval = fileChooser.showOpenDialog(null);
                     if (rval == JFileChooser.APPROVE_OPTION) {
                         String fileName = fileChooser.getSelectedFile().toString();
-                        if (fileName.lastIndexOf('/') > 0) {
-                            Beauti.setCurrentDir(fileName.substring(0, fileName.lastIndexOf('/')));
+                        if (fileName.lastIndexOf(File.separator) > 0) {
+                            Beauti.setCurrentDir(fileName.substring(0, fileName.lastIndexOf(File.separator)));
                         }
                         m_fileEntry.setText(fileName);
                     }
