@@ -34,7 +34,9 @@ import beast.evolution.alignment.Alignment;
 import beast.evolution.alignment.FilteredAlignment;
 import beast.evolution.likelihood.GenericTreeLikelihood;
 import beast.evolution.sitemodel.SiteModel;
+import beast.evolution.sitemodel.SiteModelInterface.Base;
 import beast.evolution.substitutionmodel.SubstitutionModel;
+import beast.util.BEASTClassLoader;
 import beast.util.XMLParser;
 
 
@@ -67,11 +69,12 @@ public class BeautiSubTemplate extends BEASTObject {
 //	ConnectCondition [] conditions;
     String mainID = "";
     String shortClassName;
+    public String getShortClassName() {return shortClassName;}
 
     @Override
     public void initAndValidate() {
     	try {
-        _class = Class.forName(classInput.get());
+        _class = BEASTClassLoader.forName(classInput.get());
         shortClassName = classInput.get().substring(classInput.get().lastIndexOf('.') + 1);
         instance = _class.newInstance();
         xml = xMLInput.get();//.m_sValue.get();
@@ -245,7 +248,11 @@ public class BeautiSubTemplate extends BEASTObject {
 	    transformer.setOutputProperty(OutputKeys.INDENT, "yes");
 	    transformer.transform(domSource, result);
 	    String xml = writer.toString();
-	    xml = xml.substring(xml.indexOf("<beast xmlns:beauti=\"http://beast2.org\">") + 40, xml.lastIndexOf("</beast>"));
+	    if (xml.lastIndexOf("</beast>") >= 0) {
+	    	xml = xml.substring(xml.indexOf("<beast xmlns:beauti=\"http://beast2.org\">") + 40, xml.lastIndexOf("</beast>"));
+	    } else {
+	    	xml = "";
+	    }
 	    return xml;
 	}
 
@@ -273,7 +280,9 @@ public class BeautiSubTemplate extends BEASTObject {
         // find template that created this beastObject
         String id = beastObject.getID();
         //String partition = BeautiDoc.parsePartition(id);
-        id = id.substring(0, id.indexOf("."));
+        if (id.indexOf(".") > 0) {
+        	id = id.substring(0, id.indexOf("."));
+        }
         BeautiSubTemplate template = null;
         for (BeautiSubTemplate template2 : doc.beautiConfig.subTemplatesInput.get()) {
             if (template2.matchesName(id)) {
@@ -329,7 +338,21 @@ public class BeautiSubTemplate extends BEASTObject {
         return createSubNet(new PartitionContext(partition), idMap, init);
     }
 
+    /** the subNetDepth is increased 
+     * 1. the first time a subtemplate is created
+     * 2. when a required input is missing from the template and the RequiredInputProvider tries an alternative
+     * It is also increased if (2) fails repeatedly.
+     * It is decreased when createSubNet successfully finished.
+     */
+    int subNetDepth = 0;
+    
     private BEASTInterface createSubNet(PartitionContext context, /*BeautiDoc doc,*/ HashMap<String, BEASTInterface> idMap, boolean init) {
+    	subNetDepth++;
+    	if (subNetDepth > 10) {
+    		// looks like we cannot find what we are looking for
+    		throw new IllegalArgumentException("Potential programmer error: It looks like there is a required input that was not specified in the tenmplate");
+    	}
+    	
         // wrap in a beast element with appropriate name spaces
         String _sXML = "<beast version='2.0' \n" +
                 "namespace='beast.app.beauti:beast.core:beast.evolution.branchratemodel:beast.evolution.speciation:beast.evolution.tree.coalescent:beast.core.util:beast.evolution.nuc:beast.evolution.operators:beast.evolution.sitemodel:beast.evolution.substitutionmodel:beast.evolution.likelihood:beast.evolution:beast.math.distributions'>\n" +
@@ -350,7 +373,7 @@ public class BeautiSubTemplate extends BEASTObject {
             for (BEASTInterface beastObject : beastObjects) {
                 doc.addPlugin(beastObject);
                 try {
-                	Log.warning.println("Adding " + beastObject.getClass().getName() + " " + beastObject);
+                	Log.debug.println("Adding " + beastObject.getClass().getName() + " " + beastObject);
                 } catch (Exception e) {
                 	Log.err.println("Adding " + beastObject.getClass().getName());
 				}
@@ -362,7 +385,7 @@ public class BeautiSubTemplate extends BEASTObject {
                 }
                 //System.out.println(connector.sourceID + " == " + connector.targetID);
                 if (connector.targetID != null && connector.targetID.equals("prior")) {
-                	Log.warning.println(">>> No description for connector " + connector.sourceID + " == " + connector.targetID);
+                	Log.debug.println(">>> No description for connector " + connector.sourceID + " == " + connector.targetID);
                 }
                 if (connector.getTipText() != null) {
                 	String ID = BeautiDoc.translatePartitionNames(connector.sourceID, context);
@@ -402,6 +425,7 @@ public class BeautiSubTemplate extends BEASTObject {
         }
 
         if (mainID.equals("[top]")) {
+            subNetDepth--;
             return beastObjects.get(0);
         }
 
@@ -416,14 +440,11 @@ public class BeautiSubTemplate extends BEASTObject {
 	            SiteModel.Base siteModel = (SiteModel.Base) ((GenericTreeLikelihood) treeLikelihood).siteModelInput.get();
 	            SubstitutionModel substModel = siteModel.substModelInput.get();
 	            try {
-	                siteModel.canSetSubstModel(substModel);
-	            } catch (Exception e) {
-	                Object o = doc.createInput(siteModel, siteModel.substModelInput, context);
-	                try {
-	                    siteModel.substModelInput.setValue(o, siteModel);
-	                } catch (Exception ex) {
-	                    ex.printStackTrace();
+	                if (!siteModel.canSetSubstModel(substModel)) {
+	                	setUpSubstModel(siteModel, context);
 	                }
+	            } catch (Exception e) {
+                	setUpSubstModel(siteModel, context);
 	            }
             }
 
@@ -446,11 +467,21 @@ public class BeautiSubTemplate extends BEASTObject {
             }
         }
 
+        subNetDepth--;
         //System.err.println(new XMLProducer().toXML(beastObject));
         return beastObject;
     }
 
-    public String getMainID() {
+    private void setUpSubstModel(Base siteModel, PartitionContext context) {
+        Object o = doc.createInput(siteModel, siteModel.substModelInput, context);
+        try {
+            siteModel.substModelInput.setValue(o, siteModel);
+        } catch (Exception ex) {
+            ex.printStackTrace();
+        }
+	}
+
+	public String getMainID() {
         return mainID;
     }
 
