@@ -346,7 +346,7 @@ public class AppLauncher {
 			String classPath = BeastLauncher.getPath(false, null);
              
             PackageManager.loadExternalJars();
-  			for (String jarFile : classPath.split(":")) {
+  			for (String jarFile : classPath.split(File.pathSeparator)) {
   				if (jarFile.toLowerCase().endsWith("jar")) {
   					BEASTClassLoader.classLoader.addJar(jarFile);
   				}
@@ -383,10 +383,10 @@ System.err.println("Done invoking " + packageApp.className);
         ps.println("\nAppLauncher: Run installed BEAST 2 package apps.\n" +
                         "\n" +
                         "Usage:\n" +
-                        "\tappstore\n" +
-                        "\tappstore -help\n" +
-                        "\tappstore -list [package_name]\n" +
-                        "\tappstore <app_class_name|app_description>");
+                        "\tapplauncher\n" +
+                        "\tapplauncher -help\n" +
+                        "\tapplauncher -list [package_name]\n" +
+                        "\tapplauncher <app_class_name|app_description>");
     }
 
     private void printAppList(List<PackageApp> appList, PrintStream ps) {
