@@ -12,8 +12,8 @@ public class LogCombinerLauncher extends BeastLauncher {
 
 	public static void main(String[] args) throws NoSuchMethodException, SecurityException, ClassNotFoundException, IllegalAccessException, IllegalArgumentException, InvocationTargetException, IOException {
 		if (javaVersionCheck("LogCombiner")) {
-			loadBEASTJars();
-			LogCombiner.main(args);
+			String classpath = getPath(false, null);
+			run(classpath, "beast.app.tools.LogCombiner", args);
 		}
 	}
 }
