@@ -253,8 +253,12 @@ public class TreeAnnotator {
 
         private void parseTreesBlock() throws IOException  {
             // read to first non-empty line within trees block
+        	fin.mark(1024*1024);
+        	int lineNr = this.lineNr;
             String str = readLine().trim();
             while (str.equals("")) {
+            	fin.mark(1024*1024);
+            	lineNr = this.lineNr;
                 str = readLine().trim();
             }
 
@@ -265,13 +269,16 @@ public class TreeAnnotator {
                 if (origin != -1) {
                     taxa = getIndexedTranslationMap(translationMap, origin);
                 }
+            } else {
+            	this.lineNr = lineNr;
+            	fin.reset();
             }
             // we got to the end of the translate block
-            // read bunrinCount trees
+            // read burninCount trees
             current = 0;
             while (current < burninCount && fin.ready()) {
     			str = nextLine();
-                if (str.toLowerCase().startsWith("tree ")) {
+                if (str.trim().toLowerCase().startsWith("tree ")) {
                 	current++;
                 }
             }
@@ -363,7 +370,7 @@ public class TreeAnnotator {
     		}
     		
             // read trees from NEXUS file
-            if (str.toLowerCase().startsWith("tree ")) {
+            if (str.trim().toLowerCase().startsWith("tree ")) {
             	current++;
                 final int i = str.indexOf('(');
                 if (i > 0) {
@@ -543,7 +550,7 @@ public class TreeAnnotator {
                     
                     String tree = BeautiDoc.load(targetTreeFileName);
                     
-                    if (tree.startsWith("#NEXUS")) {
+                    if (tree.trim().startsWith("#NEXUS")) {
                     	NexusParser parser2 = new NexusParser();
                     	parser2.parseFile(new File(targetTreeFileName));
                     	targetTree = parser2.trees.get(0);
