@@ -382,11 +382,13 @@ public class Logger extends BEASTObject {
                         	// we are using the BEAST console, so no input is possible
                         	throw new IllegalArgumentException();
 						}
-                        Log.info.println("Overwrite (Y/N)?:");
+                        Log.info.println("Overwrite (Y=yes/N=no/A=overwrite all)?:");
                         Log.info.flush();
                         final BufferedReader stdin = new BufferedReader(new InputStreamReader(System.in));	                        
                         final String msg = stdin.readLine();
-                        if (!msg.toLowerCase().equals("y")) {
+                        if (msg.toLowerCase().equals("a")) {
+                        	FILE_MODE = LogFileMode.overwrite;
+                        } else if (!msg.toLowerCase().equals("y")) {
                         	Log.info.println("Exiting now.");
                             System.exit(0);
                         }
@@ -411,18 +413,7 @@ public class Logger extends BEASTObject {
                     if (file.exists()) {
                         if (mode == LOGMODE.compound) {
                             // first find the sample nr offset
-                            final BufferedReader fin = new BufferedReader(new FileReader(fileName));
-                            String str = null;
-                            while (fin.ready()) {
-                                str = fin.readLine();
-                            }
-                            fin.close();
-                            assert str != null;
-                            final long sampleOffset = Long.parseLong(str.split("\\s")[0]);
-                            if (Logger.sampleOffset > 0 && sampleOffset != Logger.sampleOffset) {
-                                throw new RuntimeException("Error 400: Cannot resume: log files do not end in same sample number");
-                            }
-                            Logger.sampleOffset = sampleOffset;
+                            Logger.sampleOffset = getLogOffset();
                             // open the file for appending
                             final FileOutputStream out2 = new FileOutputStream(fileName, true);
                             m_out = new PrintStream(out2);
@@ -490,6 +481,152 @@ public class Logger extends BEASTObject {
         }
     } // openLogFile
 
+	/**
+	 * Determines the last state in a (trace or tree) log file
+	 * Tries to detect if last line is corrupted and fixes it by removing the last line if so.
+	 * Corruption is detected as follows:
+	 * For trace logs, the number of columns in the header should be the same as in the log lines.
+	 * For tree files, the last line (or one but last, if it ends with "End;") should end in a semi-column. 
+	 * @return last state of (corrected, if deemed corrupted) log file
+	 * @throws IOException
+	 */
+	protected long getLogOffset() throws IOException {
+	    final File file = new File(fileName);
+	    if (file.exists()) {
+            final BufferedReader fin = new BufferedReader(new FileReader(fileName));
+	        if (mode == LOGMODE.compound) {
+	            // first find the sample nr offset
+	            String str = null;
+	            String prevStr = null;
+	            int columnCount = -1;
+	            while (fin.ready()) {
+	            	prevStr = str;
+	                str = fin.readLine();
+	                if (str.startsWith("Sample\t")) {
+	                	columnCount = str.split("\t").length;
+	                }
+	            }
+	            fin.close();
+	            assert str != null;
+	            if (columnCount > 0 && columnCount != str.split("\t").length) {
+	            	// last trace log line does not have the same number of columns as header, 
+	            	// so assume it was corrupted (e.g. disk full, or process aborted midway). 
+	            	// Revert to previous line and fix file
+	            	try {
+		            	long offset = Long.parseLong(prevStr.split("\\s")[0]);
+		            	setLogOffset(offset);
+		            	return offset;
+	            	} catch (NumberFormatException e){
+	            		return 0;
+	            	}
+	            }	            
+            	try {
+            		return Long.parseLong(str.split("\\s")[0]);
+            	} catch (NumberFormatException e){
+            		return 0;
+            	}
+	        } else {
+	            // it is a tree logger
+	            String str = null;
+	            String prevStr = null;
+	            while (fin.ready()) {
+	            	prevStr = str;
+	                str = fin.readLine();
+	            }
+	            fin.close();
+
+	            if( str == null ) {
+	            	// empty log file
+	            	return 0;
+	            }
+                if (str.equals("End;")) {
+                    str = prevStr;
+                }
+            	if (!str.endsWith(";")) {
+                	// file contains corrupted tree
+                	// revert to previous line and fix file
+    	            final String str2 = prevStr.split("\\s+")[1];
+                	try {
+                		long offset = Long.parseLong(str2.substring(6));
+                		setLogOffset(offset);
+                		return offset;
+                	} catch (NumberFormatException e){
+                		return 0;
+                	}
+                }
+	            
+	            // determine number of the last sample
+	            final String str2 = str.split("\\s+")[1];
+	            
+            	try {
+            		return Long.parseLong(str2.substring(6));
+            	} catch (NumberFormatException e){
+            		return 0;
+            	}
+	        }
+	    }
+	    return 0;
+	}
+
+	protected void setLogOffset(long offset) throws IOException {
+	    final File file = new File(fileName);
+	    if (file.exists()) {
+	    	// back up file in case something goes wrong (e.g. an out of memory error occurs)
+	        final File treeFileBackup = new File(fileName);
+	        
+	        //final boolean ok = treeFileBackup.renameTo(new File(fileName + ".bu"));    assert ok;
+	        Files.move(treeFileBackup.toPath(), new File(fileName+".bu").toPath(), StandardCopyOption.ATOMIC_MOVE);
+	        // open the file and write back all but the last line
+	        final BufferedReader fin = new BufferedReader(new FileReader(fileName+".bu"));
+	
+	        final PrintStream out2 = new PrintStream(fileName);
+
+	        if (mode == LOGMODE.compound) {
+	            // first find the sample nr offset
+	            String str = null;
+	            while (fin.ready()) {
+	                str = fin.readLine();
+	                out2.println(str);
+                	if (!str.startsWith("#")) {
+    	                try {
+	                		final long sampleOffset = Long.parseLong(str.split("\\s")[0]);
+	                		if (offset == sampleOffset) {
+	                			break;
+	                		}
+	                	} catch (NumberFormatException e) {
+		                	// ignore
+		                }
+                	}
+	            }
+	            fin.close();
+	        } else {
+	            // it is a tree logger
+	            String str = null;
+	            while (fin.ready()) {
+	                str = fin.readLine();
+	                out2.println(str);
+	                String [] strs = str.split("\\s+");
+	                if (strs.length > 1 && strs[1].length() > 6) {
+    	                try {
+		                	final long sampleOffset = Long.parseLong(strs[1].substring(6));
+		                	if (offset == sampleOffset) {
+		                		break;
+		                	}
+	                	} catch (NumberFormatException e) {
+		                	// ignore
+		                }
+	                }
+	            }
+	            fin.close();
+	        }
+	        out2.close();
+	        
+            // it is safe to remove the backup file now
+            new File(fileName + ".bu").delete();
+	    }
+	}
+	
+	
     /**
      * log the state for given sample nr
      * *
@@ -636,6 +773,12 @@ public class Logger extends BEASTObject {
     	PrintStream m_out_alt = new PrintStream(m_out);
     	return m_out_alt;
     }
+    
+    // Returns the file name
+    public String getFileName() {
+    	return fileName;
+    }
+    
 
 
 } // class Logger
