@@ -34,6 +34,7 @@ import javax.xml.parsers.ParserConfigurationException;
 
 import org.xml.sax.SAXException;
 
+import beast.core.Input.Validate;
 import beast.core.util.CompoundDistribution;
 import beast.core.util.Evaluator;
 import beast.core.util.Log;
@@ -42,12 +43,21 @@ import beast.util.Randomizer;
 @Description("MCMC chain. This is the main element that controls which posterior " +
         "to calculate, how long to run the chain and all other properties, " +
         "which operators to apply on the state space and where to log results.")
-@Citation(value=
-        "Bouckaert RR, Heled J, Kuehnert D, Vaughan TG, Wu C-H, Xie D, Suchard MA,\n" +
-                "  Rambaut A, Drummond AJ (2014) BEAST 2: A software platform for Bayesian\n" +
-                "  evolutionary analysis. PLoS Computational Biology 10(4): e1003537"
-        , year = 2014, firstAuthorSurname = "bouckaert",
-        DOI="10.1371/journal.pcbi.1003537")
+//@Citation(value=
+//        "Bouckaert RR, Heled J, Kuehnert D, Vaughan TG, Wu C-H, Xie D, Suchard MA,\n" +
+//                "  Rambaut A, Drummond AJ (2014) BEAST 2: A software platform for Bayesian\n" +
+//                "  evolutionary analysis. PLoS Computational Biology 10(4): e1003537"
+//        , year = 2014, firstAuthorSurname = "bouckaert",
+//        DOI="10.1371/journal.pcbi.1003537")
+@Citation(value="Bouckaert, Remco, Timothy G. Vaughan, Joëlle Barido-Sottani, Sebastián Duchêne, Mathieu Fourment, \n"
+		+ "Alexandra Gavryushkina, Joseph Heled, Graham Jones, Denise Kühnert, Nicola De Maio, Michael Matschiner, \n"
+        + "Fábio K. Mendes, Nicola F. Müller, Huw A. Ogilvie, Louis du Plessis, Alex Popinga, Andrew Rambaut, \n"
+        + "David Rasmussen, Igor Siveroni, Marc A. Suchard, Chieh-Hsi Wu, Dong Xie, Chi Zhang, Tanja Stadler, \n"
+        + "Alexei J. Drummond \n"
+		+ "  BEAST 2.5: An advanced software platform for Bayesian evolutionary analysis. \n"
+		+ "  PLoS computational biology 15, no. 4 (2019): e1006650.", 
+        year = 2019, firstAuthorSurname = "bouckaert",
+		DOI="10.1371/journal.pcbi.1006650")
 public class MCMC extends Runnable {
 
     final public Input<Long> chainLengthInput =
@@ -88,7 +98,7 @@ public class MCMC extends Runnable {
     final public Input<Boolean> sampleFromPriorInput = new Input<>("sampleFromPrior", "whether to ignore the likelihood when sampling (default false). " +
             "The distribution with id 'likelihood' in the posterior input will be ignored when this flag is set.", false);
 
-    final public Input<OperatorSchedule> operatorScheduleInput = new Input<>("operatorschedule", "specify operator selection and optimisation schedule", new OperatorSchedule());
+    final public Input<OperatorSchedule> operatorScheduleInput = new Input<>("operatorschedule", "specify operator selection and optimisation schedule", new OperatorSchedule(), Validate.REQUIRED);
 
     /**
      * Alternative representation of operatorsInput that allows random selection
@@ -113,7 +123,7 @@ public class MCMC extends Runnable {
      */
     final protected int NR_OF_DEBUG_SAMPLES = 2000;
 
-    /**
+    /** 
      * Interval for storing state to disk, if negative the state will not be stored periodically *
      * Mirrors m_storeEvery input, or if this input is negative, the State.m_storeEvery input
      */
@@ -312,7 +322,7 @@ public class MCMC extends Runnable {
         Log.info.println("Start likelihood: " + oldLogLikelihood + " " + (initialisationAttempts > 1 ? "after " + initialisationAttempts + " initialisation attempts" : ""));
         if (Double.isInfinite(oldLogLikelihood) || Double.isNaN(oldLogLikelihood)) {
             reportLogLikelihoods(posterior, "");
-            throw new RuntimeException("Could not find a proper state to initialise. Perhaps try another seed.");
+            throw new RuntimeException("Could not find a proper state to initialise. Perhaps try another seed.\nSee http://www.beast2.org/2018/07/04/fatal-errors.html for other possible solutions.");
         }
 
         loggers = loggersInput.get();
@@ -346,6 +356,9 @@ public class MCMC extends Runnable {
         }
 
         // initialises log so that log file headers are written, etc.
+        if (restoreFromFile) {
+        	makeSureLogFilesAreSameLength();
+        }
         for (final Logger log : loggers) {
             log.init();
         }
@@ -368,7 +381,32 @@ public class MCMC extends Runnable {
     } // run;
 
 
-    /**
+    protected void makeSureLogFilesAreSameLength() throws IOException {
+    	// make sure log files all end in the same state
+    	long min = -1;
+    	long [] lengths = new long[loggers.size()];
+    	for (int i = 0; i < loggers.size(); i++) {
+    		Logger logger = loggers.get(i);
+    		if (!logger.isLoggingToStdout()) {
+    			long offset = logger.getLogOffset();
+    			lengths[i] = offset;
+    			min = min == -1 ? offset : Math.min(min, offset); 
+    		}
+    	}
+    	if (min == 0) {
+    		// at least one log file is empty
+    		return;
+    	}
+    	for (int i = 0; i < loggers.size(); i++) {
+    		Logger logger = loggers.get(i);
+    		if (!logger.isLoggingToStdout() && min != lengths[i]) {
+    			logger.setLogOffset(min);
+    		}
+    	}
+	}
+
+
+	/**
      * main MCMC loop 
      * @throws IOException *
      */
@@ -411,7 +449,7 @@ public class MCMC extends Runnable {
                     }
                 } else {
                     if (isTooDifferent(logLikelihood, originalLogP)) {
-                        // halt due to incorrect posterior during intial debug period
+                        // halt due to incorrect posterior during initial debug period
                         state.storeToFile(sampleNr);
                         operatorSchedule.storeToFile();
                         System.exit(1);
@@ -574,5 +612,9 @@ public class MCMC extends Runnable {
     public double robustlyCalcNonStochasticPosterior(final Distribution posterior) {
         return state.robustlyCalcNonStochasticPosterior(posterior);
     }
+    
+    public OperatorSchedule getOperatorSchedule() {
+    	return operatorSchedule;
+    }
 } // class MCMC
 
