@@ -31,6 +31,7 @@ import beast.core.parameter.Map;
 import beast.core.util.Log;
 import beast.evolution.datatype.DataType;
 import beast.evolution.datatype.StandardData;
+import beast.evolution.datatype.UserDataType;
 import beast.util.BEASTClassLoader;
 import beast.util.PackageManager;
 
@@ -326,7 +327,7 @@ public class Alignment extends Map<String> {
     protected void sanityCheckCalcPatternsSetUpAscertainment(boolean log) {
         // Sanity check: make sure sequences are of same length
         int length = counts.get(0).size();
-        if (!(m_dataType instanceof StandardData)) {
+        if (m_dataType.hasConstantCodeLength()) { // instanceof StandardData) && !(m_dataType instanceof UserDataType)) {
             for (List<Integer> seq : counts) {
                 if (seq.size() != length) {
                     throw new RuntimeException("Two sequences with different length found: " + length + " != " + seq.size());
