@@ -147,17 +147,29 @@ public interface DataType {
 	public String getCode(int code);
 
 	public String getCharacter(int code);
+	
+
+	/**
+	 * Usually, alignments have codes with constant lengths,
+	 * but occasionally (like for integer values, or user defined data types) they don't.
+	 * This information can be useful for sanity checks.  
+	 * @return true if code length is constant
+	 */
+	default public boolean hasConstantCodeLength() {
+		return true;
+	}
+
 
 	@Description(value = "Basic data type implementation, with methods for decoding and encoding sequence strings", isInheritable = false)
 	public abstract class Base extends BEASTObject implements DataType {
-		protected int stateCount;
-		protected String codeMap;
-		protected int codeLength;
+		public int stateCount;
+		public String codeMap;
+		public int codeLength;
 		/**
 		 * mapping codes to sets of states FIXME: This should be named
 		 * "mapCodeToState*List*", because that's what it does.
 		 */
-		protected int[][] mapCodeToStateSet;
+		public int[][] mapCodeToStateSet;
 
 		@Override
 		public void initAndValidate() {
@@ -407,4 +419,5 @@ public interface DataType {
 
 	} // class Base
 
+	
 } // class DataType
