@@ -326,7 +326,7 @@ public class BeagleTreeLikelihood extends TreeLikelihood {
         
         Node [] nodes = treeInput.get().getNodesAsArray();
         for (int i = 0; i < tipCount; i++) {
-        	int taxon = dataInput.get().getTaxonIndex(nodes[i].getID()); 
+        	int taxon = getTaxonIndex(nodes[i].getID(), dataInput.get());  
             if (m_bUseAmbiguities || m_bUseTipLikelihoods) {
                 setPartials(beagle, i, taxon);
             } else {
@@ -503,7 +503,27 @@ public class BeagleTreeLikelihood extends TreeLikelihood {
         beagle.setTipStates(nodeIndex, states);
     }
 
-
+    /**
+     *
+     * @param taxon the taxon name as a string
+     * @param data the alignment
+     * @return the taxon index of the given taxon name for accessing its sequence data in the given alignment,
+     *         or -1 if the taxon is not in the alignment.
+     */
+    private int getTaxonIndex(String taxon, Alignment data) {    	
+        int taxonIndex = data.getTaxonIndex(taxon);
+        if (taxonIndex == -1) {
+        	if (taxon.startsWith("'") || taxon.startsWith("\"")) {
+                taxonIndex = data.getTaxonIndex(taxon.substring(1, taxon.length() - 1));
+            }
+            if (taxonIndex == -1) {
+            	throw new RuntimeException("Could not find sequence " + taxon + " in the alignment");
+            }
+        }
+        return taxonIndex;
+	}
+    
+    
 //    public void setStates(int tipIndex, int[] states) {
 //        System.err.println("BTL:setStates");
 //        beagle.setTipStates(tipIndex, states);
