@@ -26,12 +26,6 @@
 
 package beast.evolution.likelihood;
 
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Collections;
-import java.util.List;
-import java.util.Random;
-
 import beast.core.Description;
 import beast.core.Input;
 import beast.core.State;
@@ -40,11 +34,14 @@ import beast.evolution.alignment.Alignment;
 import beast.evolution.branchratemodel.BranchRateModel;
 import beast.evolution.branchratemodel.StrictClockModel;
 import beast.evolution.sitemodel.SiteModel;
+import beast.evolution.substitutionmodel.Frequencies;
 import beast.evolution.substitutionmodel.SubstitutionModel;
 import beast.evolution.tree.Node;
 import beast.evolution.tree.Tree;
 import beast.evolution.tree.TreeInterface;
 
+import java.util.*;
+
 @Description("Calculates the probability of sequence data on a beast.tree given a site and substitution model using " +
         "a variant of the 'peeling algorithm'. For details, see" +
         "Felsenstein, Joseph (1981). Evolutionary trees from DNA sequences: a maximum likelihood approach. J Mol Evol 17 (6): 368-376.")
@@ -58,7 +55,9 @@ public class TreeLikelihood extends GenericTreeLikelihood {
     
     public static enum Scaling {none, always, _default};
     final public Input<Scaling> scaling = new Input<>("scaling", "type of scaling to use, one of " + Arrays.toString(Scaling.values()) + ". If not specified, the -beagle_scaling flag is used.", Scaling._default, Scaling.values());
-    
+
+    final public Input<Frequencies> rootFrequenciesInput =
+            new Input<>("rootFrequencies", "prior state frequencies at root, optional", Input.Validate.OPTIONAL);
 
     /**
      * calculation engine *
@@ -70,7 +69,7 @@ public class TreeLikelihood extends GenericTreeLikelihood {
      * BEASTObject associated with inputs. Since none of the inputs are StateNodes, it
      * is safe to link to them only once, during initAndValidate.
      */
-    SubstitutionModel substitutionModel;
+    protected SubstitutionModel substitutionModel;
     protected SiteModel.Base m_siteModel;
     protected BranchRateModel.Base branchRateModel;
 
@@ -334,6 +333,11 @@ public class TreeLikelihood extends GenericTreeLikelihood {
         }
     }
 
+    // for testing
+    public double[] getRootPartials() {
+        return m_fRootPartials.clone();
+    }
+
     /**
      * Calculate the log likelihood of the current state.
      *
@@ -453,8 +457,6 @@ public class TreeLikelihood extends GenericTreeLikelihood {
                 if (node.isRoot()) {
                     // No parent this is the root of the beast.tree -
                     // calculate the pattern likelihoods
-                    final double[] frequencies = //m_pFreqs.get().
-                            substitutionModel.getFrequencies();
 
                     final double[] proportions = m_siteModel.getCategoryProportions(node);
                     likelihoodCore.integratePartials(node.getNr(), proportions, m_fRootPartials);
@@ -467,7 +469,11 @@ public class TreeLikelihood extends GenericTreeLikelihood {
                         }
                     }
 
-                    likelihoodCore.calculateLogLikelihoods(m_fRootPartials, frequencies, patternLogLikelihoods);
+                    double[] rootFrequencies = substitutionModel.getFrequencies();
+                    if (rootFrequenciesInput.get() != null) {
+                        rootFrequencies = rootFrequenciesInput.get().getFreqs();
+                    }
+                    likelihoodCore.calculateLogLikelihoods(m_fRootPartials, rootFrequencies, patternLogLikelihoods);
                 }
 
             }
