@@ -1,14 +1,5 @@
 package beast.evolution.tree;
 
-import java.time.LocalDate;
-import java.time.format.DateTimeFormatter;
-import java.time.format.DateTimeParseException;
-import java.util.Arrays;
-import java.util.Date;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-
 import beast.core.BEASTObject;
 import beast.core.Description;
 import beast.core.Input;
@@ -16,6 +7,11 @@ import beast.core.Input.Validate;
 import beast.core.util.Log;
 import beast.evolution.alignment.TaxonSet;
 
+import java.time.LocalDate;
+import java.time.format.DateTimeFormatter;
+import java.time.format.DateTimeParseException;
+import java.util.*;
+
 
 @Description("A trait set represent a collection of properties of taxons, for the use of initializing a tree. " +
         "The traits are represented as text content in taxon=value form, for example, for a date trait, we" +
@@ -26,6 +22,13 @@ import beast.evolution.alignment.TaxonSet;
         "other traits can be supported as well.")
 public class TraitSet extends BEASTObject {
 
+    /**
+     * @return a string describing the type of date that this trait represents. could be null.
+     */
+    public String getDateType() {
+        return traitNameInput.get();
+    }
+
     public enum Units {
         year, month, day
     }
@@ -42,6 +45,7 @@ public class TraitSet extends BEASTObject {
     final public static String DATE_TRAIT = "date";
     final public static String DATE_FORWARD_TRAIT = "date-forward";
     final public static String DATE_BACKWARD_TRAIT = "date-backward";
+    final public static String AGE_TRAIT = "age";
 
     /**
      * String values of taxa in order of taxons in alignment*
@@ -51,11 +55,11 @@ public class TraitSet extends BEASTObject {
     /**
      * double representation of taxa value *
      */
-    double[] values;
-    double minValue;
-    double maxValue;
-    
-    Map<String, Integer> map;
+    protected double[] values;
+    protected double minValue;
+    protected double maxValue;
+
+    protected Map<String, Integer> map;
 
     /**
      * Whether or not values are ALL numeric.
@@ -88,21 +92,22 @@ public class TraitSet extends BEASTObject {
                 throw new IllegalArgumentException("Trait (" + taxonID + ") is not a known taxon. Spelling error perhaps?");
             }
             taxonValues[taxonNr] = normalize(strs[1]);
-            values[taxonNr] = parseDouble(taxonValues[taxonNr]);
+            try {
+                values[taxonNr] = convertValueToDouble(taxonValues[taxonNr]);
+            } catch (DateTimeParseException ex) {
+                Log.err.println("Failed to parse date '" + taxonValues[taxonNr] + "' using format '" + dateTimeFormatInput.get() + "'.");
+                System.exit(1);
+            } catch (IllegalArgumentException ex) {
+                Log.err.println("Failed to parse date '" + taxonValues[taxonNr] + "'.");
+                System.exit(1);
+            }
+
             map.put(taxonID, taxonNr);
             
             if (Double.isNaN(values[taxonNr]))
                 numeric = false;
         }
 
-        // sanity check: did we cover all taxa?
-        for (int i = 0; i < labels.size(); i++) {
-            if (taxonValues[i] == null) {
-                Log.warning.println("WARNING: no trait specified for " + labels.get(i) +": Assumed to be 0");
-                map.put(labels.get(i), i);
-            }
-        }
-
         // find extremes
         minValue = values[0];
         maxValue = values[0];
@@ -111,13 +116,26 @@ public class TraitSet extends BEASTObject {
             maxValue = Math.max(maxValue, value);
         }
 
+        // sanity check: did we cover all taxa?
+        double defaultValue = 0;
+        if (traitNameInput.get().equals(DATE_TRAIT) || traitNameInput.get().equals(DATE_FORWARD_TRAIT)) {
+        	defaultValue = maxValue;
+        }
+        for (int i = 0; i < labels.size(); i++) {
+            if (taxonValues[i] == null) {
+                Log.warning.println("WARNING: no trait specified for " + labels.get(i) +": Assumed to be " + defaultValue);
+                map.put(labels.get(i), i);
+                values[i] = defaultValue;
+            }
+        }
+
         if (traitNameInput.get().equals(DATE_TRAIT) || traitNameInput.get().equals(DATE_FORWARD_TRAIT)) {
             for (int i = 0; i < labels.size(); i++) {
                 values[i] = maxValue - values[i];
             }
         }
 
-        if (traitNameInput.get().equals(DATE_BACKWARD_TRAIT)) {
+        if (traitNameInput.get().equals(DATE_BACKWARD_TRAIT) || traitNameInput.get().equals(AGE_TRAIT)) {
             for (int i = 0; i < labels.size(); i++) {
                 values[i] = values[i] - minValue;
             }
@@ -167,59 +185,54 @@ public class TraitSet extends BEASTObject {
     /**
      * see if we can convert the string to a double value *
      */
-    private double parseDouble(String str) {
+    public double convertValueToDouble(String str) {
         // default, try to interpret the string as a number
         try {
             return Double.parseDouble(str);
         } catch (NumberFormatException e) {
             // does not look like a number
-                if (traitNameInput.get().equals(DATE_TRAIT) ||
-                        traitNameInput.get().equals(DATE_FORWARD_TRAIT) ||
-                        traitNameInput.get().equals(DATE_BACKWARD_TRAIT)) {
+            if (traitNameInput.get().equals(DATE_TRAIT) ||
+                    traitNameInput.get().equals(DATE_FORWARD_TRAIT) ||
+                    traitNameInput.get().equals(DATE_BACKWARD_TRAIT)) {
 
-                        try {
-                            double year;
-                            if (dateTimeFormatInput.get() == null) {
-                                if (str.matches(".*[a-zA-Z].*")) {
-                                        str = str.replace('/', '-');
-                                }
-                                // following is deprecated, but the best thing around at the moment
-                                // see also comments in TipDatesInputEditor
-                                long date = Date.parse(str);
-                                year = 1970.0 + date / (60.0 * 60 * 24 * 365 * 1000);
-                                Log.warning.println("No date/time format provided, using default parsing: '" + str + "' parsed as '" + year + "'");
-                            } else {
-                                DateTimeFormatter formatter = DateTimeFormatter.ofPattern(dateTimeFormatInput.get());
-                                LocalDate date = LocalDate.parse(str, formatter);
-
-                                Log.warning.println("Using format '" + dateTimeFormatInput.get() + "' to parse '" + str +
-                                        "' as: " + (date.getYear() + (date.getDayOfYear()-1.0) / (date.isLeapYear() ? 366.0 : 365.0)));
-
-                                year = date.getYear() + (date.getDayOfYear()-1.0) / (date.isLeapYear() ? 366.0 : 365.0);
-                            }
-
-                            switch (unitsInput.get()) {
-                                case month:
-                                    return year * 12.0;
-                                case day:
-                                    return year * 365;
-                                default:
-                                    return year;
-                            }
-                        } catch (DateTimeParseException e2) {
-                            Log.err.println("Failed to parse date '" + str + "' using format '" + dateTimeFormatInput.get() + "'");
-                            System.exit(1);
-                        }
+                double year;
+                if (dateTimeFormatInput.get() == null) {
+                    if (str.matches(".*[a-zA-Z].*")) {
+                        str = str.replace('/', '-');
                     }
+                    // following is deprecated, but the best thing around at the moment
+                    // see also comments in TipDatesInputEditor
+                    long date = Date.parse(str);
+                    year = 1970.0 + date / (60.0 * 60 * 24 * 365 * 1000);
+                    Log.warning.println("No date/time format provided, using default parsing: '" + str + "' parsed as '" + year + "'");
+                } else {
+                    DateTimeFormatter formatter = DateTimeFormatter.ofPattern(dateTimeFormatInput.get());
+                    LocalDate date = LocalDate.parse(str, formatter);
+
+                    Log.warning.println("Using format '" + dateTimeFormatInput.get() + "' to parse '" + str +
+                            "' as: " + (date.getYear() + (date.getDayOfYear()-1.0) / (date.isLeapYear() ? 366.0 : 365.0)));
+
+                    year = date.getYear() + (date.getDayOfYear()-1.0) / (date.isLeapYear() ? 366.0 : 365.0);
                 }
-        //return 0;
+
+                switch (unitsInput.get()) {
+                    case month:
+                        return year * 12.0;
+                    case day:
+                        return year * 365;
+                    default:
+                        return year;
+                }
+            }
+        }
+
         return Double.NaN;
-    } // parseStrings
+    }
 
     /**
      * remove start and end spaces
      */
-    String normalize(String str) {
+    protected String normalize(String str) {
         if (str.charAt(0) == ' ') {
             str = str.substring(1);
         }
@@ -229,17 +242,24 @@ public class TraitSet extends BEASTObject {
         return str;
     }
 
+    /**
+     * Retrieve absolute date from height above most recent sample.
+     *
+     * @param height age before most recent sample.
+     * @return date, which may be either backward-time or forward-time depending
+     * on the trait.  If trait type is not defined, the height itself is returned.
+     */
     public double getDate(double height) {
         if (traitNameInput.get().equals(DATE_TRAIT) || traitNameInput.get().equals(DATE_FORWARD_TRAIT)) {
             return maxValue - height;
         }
 
-        if (traitNameInput.get().equals(DATE_BACKWARD_TRAIT)) {
+        if (traitNameInput.get().equals(DATE_BACKWARD_TRAIT) || traitNameInput.get().equals(AGE_TRAIT)) {
             return minValue + height;
         }
         return height;
     }
-    
+
     /**
      * Determines whether trait is recognised as specifying taxa dates.
      * @return true if this is a date trait.
@@ -247,7 +267,7 @@ public class TraitSet extends BEASTObject {
     public boolean isDateTrait() {
         return traitNameInput.get().equals(DATE_TRAIT)
                 || traitNameInput.get().equals(DATE_FORWARD_TRAIT)
-                || traitNameInput.get().equals(DATE_BACKWARD_TRAIT);
+                || traitNameInput.get().equals(DATE_BACKWARD_TRAIT) || traitNameInput.get().equals(AGE_TRAIT);
     }
 
     /**
