@@ -1,11 +1,6 @@
 package beast.evolution.tree;
 
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.Comparator;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Set;
+import java.util.*;
 
 /**
  * @author Alexei Drummond and Alexandra Gavryushkina
@@ -32,6 +27,26 @@ public class TreeUtils {
         }
     }
 
+    public static SortedSet<String> rotateTreeAlphabetically(Node node) {
+        if (node.isLeaf()) {
+            TreeSet leafSet = new TreeSet();
+            leafSet.add(node.getID());
+            return leafSet;
+        } else {
+
+            SortedSet<String> left = rotateTreeAlphabetically(node.getLeft());
+            SortedSet<String> right = rotateTreeAlphabetically(node.getRight());
+
+            if (left.first().compareTo(right.first()) > 0) {
+                Node temp = node.getLeft();
+                node.setLeft(node.getRight());
+                node.setRight(temp);
+            }
+            left.addAll(right);
+            return left;
+        }
+    }
+
     public static Comparator<Node> createNodeDensityComparator() {
 
         return (node1, node2) -> node2.getLeafNodeCount() - node1.getLeafNodeCount();
@@ -264,17 +279,30 @@ public class TreeUtils {
      */
     public static Set<String> getDescendantLeaves(Tree tree, Node node) {
 
-        HashSet<String> set = new HashSet<>();
+        TreeSet<String> set = new TreeSet<>();
         getDescendantLeaves(tree, node, set);
         return set;
     }
 
+    /**
+     * @param tree the tree
+     * @param node the node to get names of leaves below
+     * @return a set of taxa names (as strings) of the leaf nodes descended from the given node.
+     */
+    public static List<String> getDescendantLeavesSortedList(Tree tree, Node node) {
+
+        List<String> list = new ArrayList<>();
+        getDescendantLeaves(tree, node, list);
+        Collections.sort(list);
+        return list;
+    }
+
     /**
      * @param tree the tree
      * @param node the node to get name of leaves below
      * @param set  will be populated with taxa names (as strings) of the leaf nodes descended from the given node.
      */
-    private static void getDescendantLeaves(Tree tree, Node node, Set<String> set) {
+    private static void getDescendantLeaves(Tree tree, Node node, Collection<String> set) {
 
         if (node.isLeaf()) {
             set.add(tree.getTaxonId(node));
@@ -381,5 +409,7 @@ public class TreeUtils {
         }
         return idx;
     }
+
+
 }
 
