@@ -19,7 +19,7 @@ public class Normal extends ParametricDistribution {
     final public Input<RealParameter> sigmaInput = new Input<>("sigma", "standard deviation of the normal distribution, defaults to 1");
     final public Input<RealParameter> tauInput = new Input<>("tau", "precission of the normal distribution, defaults to 1", Validate.XOR, sigmaInput);
 
-    static org.apache.commons.math.distribution.NormalDistribution dist = new NormalDistributionImpl(0, 1);
+    org.apache.commons.math.distribution.NormalDistribution dist = new NormalDistributionImpl(0, 1);
 
     @Override
     public void initAndValidate() {
