@@ -35,8 +35,6 @@ package beast.util;
 import beast.app.BEASTVersion;
 import beast.app.util.Arguments;
 import beast.app.util.Utils6;
-import beast.core.BEASTInterface;
-import beast.core.BEASTObjectStore;
 import beast.core.util.Log;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
@@ -62,7 +60,6 @@ import java.nio.channels.ReadableByteChannel;
 import java.util.*;
 import java.util.jar.JarEntry;
 import java.util.jar.JarFile;
-import java.util.jar.JarInputStream;
 import java.util.zip.ZipEntry;
 import java.util.zip.ZipFile;
 
@@ -91,7 +88,7 @@ public class PackageManager {
     public final static String TO_INSTALL_LIST_FILE = "toInstallList";
     public final static String BEAST_PACKAGE_NAME = "BEAST";
 
-    public final static String PACKAGES_XML = "https://raw.githubusercontent.com/CompEvol/CBAN/master/packages2.5.xml";
+    public final static String PACKAGES_XML = "https://raw.githubusercontent.com/CompEvol/CBAN/master/packages2.6.xml";
 //    public final static String PACKAGES_XML = "file:///Users/remco/workspace/beast2/packages.xml";
     public final static String ARCHIVE_DIR = "archive";
     // flag to indicate archive directory and version numbers in directories are required
@@ -1411,6 +1408,7 @@ public class PackageManager {
 
         for (String path : classpath.split(pathSep)) {
             //Log.debug.println("loadallclasses " + path);
+            path = path.replaceAll("%20", " ");
             File filepath = new File(path);
 
             if (filepath.isDirectory()) {
@@ -1966,107 +1964,13 @@ public class PackageManager {
 		return buf.toString();
 	}
 
-	/** keep track of which class comes from a particular package.
-     * It maps a full class name onto a package name + " v" + package version
-     * e.g. "bModelTest v0.3.2"
-     */
-    private static Map<String, String> classToPackageMap = new HashMap<String, String>();
-    
-    /**  maps package name to a Package object, which contains info on whether 
+	/**  maps package name to a Package object, which contains info on whether 
      * and which version is installed. This is initialised when loadExternalJars()
      * is called, which happens at the start of BEAST, BEAUti and many utilities.
      */
     private static TreeMap<String, Package> packages = new TreeMap<String, Package>();
    
-    public static Map<String, String> getClassToPackageMap() {
-    	if (classToPackageMap.size() == 0) {
-            for (String jarDirName : getBeastDirectories()) {
-            	initPackageMap(jarDirName);
-            }
-    	}
-    	return classToPackageMap;
-    }
-
-    /** return set of Strings in the format of classToPackageMap (like "bModelTest v0.3.2")
-     * for all packages used by o and its predecessors in the model graph.
-     */
-    public static Set<String> getPackagesAndVersions(Object o) {
-    	Set<String> packagesAndVersions = new LinkedHashSet<String>();
-    	getPackagesAndVersions(o, packagesAndVersions);
-    	return packagesAndVersions;
-    }
-    
-    /** traverse model graph starting at o, and collect packageAndVersion strings
-     * along the way.
-     */
-    private static void getPackagesAndVersions(Object o, Set<String> packagesAndVersions) {
-    	String packageAndVersion = classToPackageMap.get(o.getClass().getName());
-    	if (packageAndVersion != null) {
-    		packagesAndVersions.add(packageAndVersion);
-    	}
-    	for (BEASTInterface o2 : BEASTObjectStore.listActiveBEASTObjects(o)) {
-    		getPackagesAndVersions(o2, packagesAndVersions);
-    	}
-	}
-    
-    private static void initPackageMap(String jarDirName) {
-        try {
-            File versionFile = new File(jarDirName + "/version.xml");
-            String packageNameAndVersion = null;
-            if (versionFile.exists()) {
-                try {
-                    // print name and version of package
-                    DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
-                    Document doc = factory.newDocumentBuilder().parse(versionFile);
-                    Element packageElement = doc.getDocumentElement();
-                    packageNameAndVersion = packageElement.getAttribute("name") + " v" + packageElement.getAttribute("version");
-                    Log.warning.println("Loading package " + packageNameAndVersion);
-                    Utils6.logToSplashScreen("Loading package " + packageNameAndVersion);
-                } catch (Exception e) {
-                    // too bad, won't print out any info
-
-                    // File is called version.xml, but is not a Beast2 version file
-                    // Log.debug.print("Skipping "+jarDirName+" (not a Beast2 package)");
-                }
-            }
-            File jarDir = new File(jarDirName + "/lib");
-            if (!jarDir.exists()) {
-                jarDir = new File(jarDirName + "\\lib");
-            }
-            if (jarDir.exists() && jarDir.isDirectory()) {
-                for (String fileName : jarDir.list()) {
-                    if (fileName.endsWith(".jar")) {
-                        Log.debug.print("Probing: " + fileName + " ");
-                        // check that we are not reload existing classes
-                        try {
-                            JarInputStream jarFile = new JarInputStream
-                                    (new FileInputStream(jarDir.getAbsolutePath() + "/" + fileName));
-                            JarEntry jarEntry;
-                            while ((jarEntry = jarFile.getNextJarEntry()) != null) {
-                                if ((jarEntry.getName().endsWith(".class"))) {
-                                    String className = jarEntry.getName().replaceAll("/", "\\.");
-                                    className = className.substring(0, className.lastIndexOf('.'));
-                                    if (packageNameAndVersion != null) {
-                                        classToPackageMap.put(className, packageNameAndVersion);
-                                    }
-                                }
-                            }
-                            jarFile.close();
-                        } catch (Exception e) {
-                            e.printStackTrace();
-                        }
-                    }
-                }
-            }
-        } catch (Exception e) {
-            // File exists, but cannot open the file for some reason
-            Log.debug.println("Skipping "+jarDirName+"/version.xml (unable to open file");
-            Log.warning.println("Skipping "+jarDirName+"/version.xml (unable to open file");
-        }
-		
-	}
-
-	/** test whether a package with given name and version is available.
+    /** test whether a package with given name and version is available.
      * @param pkgname
      * @param pkgversion ignored for now
      * @return
