@@ -25,55 +25,39 @@
 package beast.util;
 
 
-import static beast.util.XMLParserUtils.processPlates;
-import static beast.util.XMLParserUtils.replaceVariable;
-
-import java.io.File;
-import java.io.IOException;
-import java.io.PrintStream;
-import java.io.StringReader;
-import java.lang.annotation.Annotation;
-import java.lang.reflect.Array;
-import java.lang.reflect.Constructor;
-import java.lang.reflect.InvocationTargetException;
-import java.lang.reflect.Method;
-import java.lang.reflect.Modifier;
-import java.lang.reflect.Type;
-import java.util.ArrayList;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Set;
-
-import javax.xml.parsers.DocumentBuilderFactory;
-import javax.xml.parsers.ParserConfigurationException;
-
-import org.w3c.dom.Document;
-import org.w3c.dom.Element;
-import org.w3c.dom.NamedNodeMap;
-import org.w3c.dom.Node;
-import org.w3c.dom.NodeList;
-import org.xml.sax.InputSource;
-import org.xml.sax.SAXException;
-
+import beast.app.beauti.BeautiDoc;
 import beast.app.beauti.PartitionContext;
-import beast.core.BEASTInterface;
-import beast.core.BEASTObjectStore;
-import beast.core.Distribution;
-import beast.core.Input;
-import beast.core.Input.Validate;
-import beast.core.Logger;
-import beast.core.Operator;
-import beast.core.Param;
+import beast.core.*;
 import beast.core.Runnable;
-import beast.core.State;
-import beast.core.VirtualBEASTObject;
+import beast.core.Input.Validate;
+import beast.core.Logger.LogFileMode;
 import beast.core.parameter.Parameter;
 import beast.core.parameter.RealParameter;
 import beast.core.util.Log;
 import beast.evolution.alignment.Alignment;
 import beast.evolution.alignment.Sequence;
 import beast.evolution.tree.Tree;
+import org.w3c.dom.*;
+import org.xml.sax.InputSource;
+import org.xml.sax.SAXException;
+
+import javax.xml.parsers.DocumentBuilderFactory;
+import javax.xml.parsers.ParserConfigurationException;
+
+import java.io.BufferedReader;
+import java.io.ByteArrayInputStream;
+import java.io.File;
+import java.io.FileWriter;
+import java.io.IOException;
+import java.io.InputStreamReader;
+import java.io.PrintStream;
+import java.io.StringReader;
+import java.lang.annotation.Annotation;
+import java.lang.reflect.*;
+import java.util.*;
+
+import static beast.util.XMLParserUtils.processPlates;
+import static beast.util.XMLParserUtils.replaceVariable;
 
 
 /**
@@ -202,6 +186,7 @@ public class XMLParser {
 
 
     static HashMap<String, String> element2ClassMap;
+    static HashMap<String, String> oldClass2ClassMap;
     static Set<String> reservedElements;
     static {
         element2ClassMap = new HashMap<>();
@@ -218,6 +203,30 @@ public class XMLParser {
         for (final String element : element2ClassMap.keySet()) {
         	reservedElements.add(element);
         }
+        
+        // Parse version.xml files
+        // Encoded in version.xml as <map from="old.class.Name" to="new.class.Name"/>
+        // This helps with refactoring packages while keeping old XML parseable.
+        oldClass2ClassMap = new HashMap<>();
+        for (String dir : PackageManager.getBeastDirectories()) {
+        	File file = new File(dir + "/version.xml");
+        	if (file.exists()) {
+        		try {
+                    DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
+                    Document doc = factory.newDocumentBuilder().parse(file);
+                    doc.normalize();
+                    NodeList nodes = doc.getElementsByTagName("map");
+                    for (int i = 0; i < nodes.getLength(); i++) {
+                        Element map = (Element) nodes.item(i);
+                        String fromClass = map.getAttribute("from");
+                        String toClass = map.getAttribute("to");
+                        oldClass2ClassMap.put(fromClass, toClass);
+                    }
+                } catch (ParserConfigurationException|SAXException|IOException e) {
+                    e.printStackTrace();
+                }        		
+        	}
+        }
     }
 
     public static class NameValuePair {
@@ -235,9 +244,10 @@ public class XMLParser {
 		}
 	}
 
-    List<BEASTInterface> beastObjectsWaitingToInit;
-    List<Node> nodesWaitingToInit;
+    List<BEASTInterface> beastObjectsWaitingToInit = new ArrayList<>();
+    List<Node> nodesWaitingToInit = new ArrayList<>();
 	java.util.Map<String,String> parserDefinitions;
+	boolean hasParserDefinitionsFromFile = false;
 
     public HashMap<String, String> getElement2ClassMap() {
         return element2ClassMap;
@@ -258,17 +268,27 @@ public class XMLParser {
      */
     RequiredInputProvider requiredInputProvider = null;
     PartitionContext partitionContext = null;
+    
+    /**
+     * if outFile is not null, an XML file merged with parser definitions processed 
+     * will be saved here
+     */
+    String outFile = null;
+    
 
     public XMLParser() {
-        beastObjectsWaitingToInit = new ArrayList<>();
-        nodesWaitingToInit = new ArrayList<>();
+        this.parserDefinitions = new HashMap<>();
     }
     
 	public XMLParser(java.util.Map<String,String> parserDefinitions) {
-		this();
 		this.parserDefinitions = parserDefinitions;
 	}
 
+	public XMLParser(java.util.Map<String,String> parserDefinitions, String outFile, boolean hasParserDefinitionsFromFile) {
+		this.parserDefinitions = parserDefinitions;
+		this.outFile = outFile;
+		this.hasParserDefinitionsFromFile = hasParserDefinitionsFromFile;
+	}
 
 
     public Runnable parseFile(final File file) throws SAXException, IOException, ParserConfigurationException, XMLParserException {
@@ -279,7 +299,15 @@ public class XMLParser {
         // parse the XML file into a DOM document
         final DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
         //factory.setValidating(true);
-        doc = factory.newDocumentBuilder().parse(file);
+        String xml = BeautiDoc.load(file);
+        xml = processDefaultValues(xml);
+        for (String key: parserDefinitions.keySet()) {
+        	xml = xml.replaceAll("\\$\\(" + key + "\\)", parserDefinitions.get(key));
+        }
+        
+        outputXML(xml);
+        
+        doc = factory.newDocumentBuilder().parse(new ByteArrayInputStream(xml.getBytes()));
         doc.normalize();
         processPlates(doc,PLATE_ELEMENT);
 
@@ -293,8 +321,8 @@ public class XMLParser {
         replaceVariable(doc.getElementsByTagName(BEAST_ELEMENT).item(0), "filebase", baseName);
 
         // Substitute occurrences of "$(seed)" with RNG seed
-//        replaceVariable(doc.getElementsByTagName(BEAST_ELEMENT).item(0), "seed",
-//                String.valueOf(Randomizer.getSeed()));
+        replaceVariable(doc.getElementsByTagName(BEAST_ELEMENT).item(0), "seed",
+                String.valueOf(Randomizer.getSeed()));
         
         if (parserDefinitions != null) {
         	for (String name : parserDefinitions.keySet()) {
@@ -323,6 +351,102 @@ public class XMLParser {
     } // parseFile
 
     /**
+     * Gather all user defined variable default values. These are defined in the XML 
+     * as $(name=default_value)
+     * @param xml
+     * @return xml with default values removed
+     */
+    private String processDefaultValues(String xml) {
+    	if (xml.indexOf("$(") == -1) {
+    		// no default values in the XML
+			return xml;
+		}
+    	// find parser definitions for default values
+    	Map<String,String> defaults = new HashMap<>();
+    	StringBuilder b = new StringBuilder();
+    	for (int i = 0; i < xml.length(); i++) {
+    		char c = xml.charAt(i);
+    		if (c == '$' && i < xml.length() - 1 && xml.charAt(i+1) == '(') {
+    			int j = i + 1;
+    			int k = -1;
+    			while (j < xml.length() && xml.charAt(j) != ')') {
+    				if (xml.charAt(j) == '=') {
+    					k = j;
+    				}
+    				j++;
+    			}
+    			if (k > 0) {
+    				// default found
+    				String name = xml.substring(i + 2, k);
+    				String value = xml.substring(k + 1, j);
+    				if (defaults.containsKey(name)) {
+    					throw new IllegalArgumentException("user defined parameter '" + name + "' has multiple default values defined");
+    				}
+    				defaults.put(name,  value);
+    				b.append("$(" + name + ")");
+    			} else {
+    				String name = xml.substring(i + 2, j);
+    				b.append("$(" + name + ")");
+    			}
+				i = j;
+    		} else {
+    			b.append(c);
+    		}
+    	}
+    	
+    	// update parserDefinitions
+    	for (String name : defaults.keySet()) {
+    		if (!parserDefinitions.containsKey(name)) {
+    			parserDefinitions.put(name, defaults.get(name));
+    		}
+    	}
+		return b.toString();
+	}
+
+	private void outputXML(String xml) {
+        try {
+        	if (parserDefinitions != null && parserDefinitions.size() > 0 && 
+        			// do not write file when resuming and no -DFout is specified
+        			!(Logger.FILE_MODE== LogFileMode.resume && outFile == null) &&
+        			// write file when -DF or -DFout option is used  
+        			(hasParserDefinitionsFromFile || outFile != null)) {
+	    		Log.warning("Outputting merged file to " + outFile);
+                File file2 = new File(outFile);
+                if (file2.exists() && Logger.FILE_MODE != LogFileMode.overwrite) {
+                    if (Logger.FILE_MODE == LogFileMode.only_new_or_exit) {
+                        Log.err.println("Trying to write file " + outFile + " but the file already exists. Exiting now.");
+                        throw new RuntimeException("Use overwrite or resume option, or remove the file");
+                    }
+                    // Check with user what to do next
+                    Log.info.println("Trying to write file " + outFile + " but the file already exists (perhaps use the -overwrite flag?).");
+                    if (System.getProperty("beast.useWindow") != null) {
+                    	// we are using the BEAST console, so no input is possible
+                    	throw new IllegalArgumentException();
+					}
+                    Log.info.println("Overwrite (Y=yes/N=no/A=overwrite all)?:");
+                    Log.info.flush();
+                    final BufferedReader stdin = new BufferedReader(new InputStreamReader(System.in));	                        
+                    final String msg = stdin.readLine();
+                    if (msg.toLowerCase().equals("a")) {
+                    	if (Logger.FILE_MODE != LogFileMode.resume) {
+                    		Logger.FILE_MODE = LogFileMode.overwrite;
+                    	}
+                    } else if (!msg.toLowerCase().equals("y")) {
+                    	Log.info.println("Exiting now.");
+                        System.exit(0);
+                    }
+                }
+		        FileWriter outfile = new FileWriter(outFile);
+		        outfile.write(xml);
+		        outfile.close();
+        	}
+        } catch (IOException e) {
+        	// ignore
+    		Log.warning("Something went wroting outputting merged file: " + e.getMessage());
+        }
+    }
+
+	/**
      * extract all elements (runnable or not) from an XML fragment.
      * Useful for retrieving all non-runnable elements when a template
      * is instantiated by Beauti 
@@ -372,7 +496,7 @@ public class XMLParser {
         for (int i = 0; i < children.getLength(); i++) {
             if (children.item(i).getNodeType() == Node.ELEMENT_NODE) {
                 final Node child = children.item(i);
-                Log.warning.println(child.getNodeName());
+                Log.debug.println(child.getNodeName());
                 if (!child.getNodeName().equals(MAP_ELEMENT)) {
                     beastObjects.add(createObject(child, BEAST_INTERFACE_CLASS));
                 }
@@ -473,6 +597,11 @@ public class XMLParser {
 
     public List<BEASTInterface> parseBareFragments(final String xml, final boolean initialise) throws XMLParserException, SAXException, IOException, ParserConfigurationException {
         needsInitialisation = initialise;
+
+        IDMap = new HashMap<>();
+        likelihoodMap = new HashMap<>();
+        IDNodeMap = new HashMap<>();
+
         // parse the XML fragment into a DOM document
         final DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
         doc = factory.newDocumentBuilder().parse(new InputSource(new StringReader(xml)));
@@ -762,6 +891,10 @@ public class XMLParser {
                     }
                 } catch (ClassNotFoundException e) {
                     // class does not exist -- try another namespace
+                	if (oldClass2ClassMap.containsKey(nameSpace + specClass)) {
+                		clazzName = oldClass2ClassMap.get(nameSpace + specClass);
+                		isDone = true;
+                	}
                 }
             }
 		}
@@ -830,14 +963,16 @@ public class XMLParser {
 		} catch (InstantiationException e) {
 			// we only get here when the class exists, but cannot be
 			// created for instance because it is abstract
-			throw new XMLParserException(node, "Cannot instantiate class. Please check the spec attribute.", 1006);
+            String msg = "Class " + clazzName + " exists but cannot to be instantiated.\n" +
+                    "Please check if the class has the zero-argument constructor.";
+			throw new XMLParserException(node, msg, 1006);
 		} catch (ClassNotFoundException e) {
 			// ignore -- class was found in beastObjectNames before
 		} catch (IllegalAccessException e) {
 			// try to call static method clazzName.newInstance()
 			Class<?> c;
 			try {
-				c = Class.forName(clazzName);
+				c = BEASTClassLoader.forName(clazzName);
 				Method newInstance;
 				newInstance = c.getDeclaredMethod("newInstance");
 				if (!Modifier.isStatic(newInstance.getModifiers())) {
@@ -997,7 +1132,7 @@ public class XMLParser {
 							try {
 								if (!BEASTObjectStore.isPrimitiveType(typeName)) {
 									List<Object> values = XMLParser.getListOfValues(param, inputInfo);
-									Object array = java.lang.reflect.Array.newInstance(Class.forName(typeName), values.size());
+									Object array = java.lang.reflect.Array.newInstance(BEASTClassLoader.forName(typeName), values.size());
 									for (int k = 0; k < values.size(); k++) {
 										Object v = values.get(k);
 										if (v instanceof VirtualBEASTObject) {
@@ -1142,7 +1277,10 @@ public class XMLParser {
                 // resolve base class
                 String specClass = BEAST_INTERFACE_CLASS;
                 if (element2ClassMap.containsKey(element)) {
-                	specClass = element2ClassMap.get(element);
+                    final String idref = getAttribute(child, "idref");
+                    if (idref == null) {
+                    	specClass = element2ClassMap.get(element);
+                    }
                 }
                 final String spec = getAttribute(child, "spec");
                 if (spec != null) {
